@@ -48,6 +48,10 @@ class BinhostsBase(object):
                     res = data
             except urllib2.URLError:
                 res = ""
+            except BaseException as e:
+                if isinstance(e, KeyboardInterrupt):
+                    raise
+                res = ""
             self.binhosts_data[binhost] = res
         return self.binhosts_data[binhost]
 
@@ -72,7 +76,6 @@ class BinhostsBase(object):
         except BaseException as e:
             if isinstance(e, KeyboardInterrupt):
                 raise
-            print str(e)
             pass
         return "", -1, False, True
 
