@@ -16,7 +16,9 @@
 from functools import wraps
 
 from itertools import tee
+from functools import total_ordering
 from contextlib import contextmanager
+
 try:
     import json as json_module
 except ImportError:
@@ -359,6 +361,7 @@ def max_default(iterable, key=lambda x: x, default=None):
     except ValueError:
         return default
 
+
 def traverse(o, tree_types=(list, tuple)):
     """
     Вернуть последовательно все элемены списка, "распаковов" встроенные
@@ -374,3 +377,23 @@ def traverse(o, tree_types=(list, tuple)):
                 yield subvalue
     else:
         yield o
+
+
+@total_ordering
+class ReverseKey(object):
+    """
+    Объект для создания ключей обратной сортировки
+
+    s = [("A","B"), ("A","C"), ("B","A")]
+    sorted(s, key=lambda x: (x[0], ReverseKey(x[1]))
+    """
+    __slots__ = ['data']
+
+    def __init__(self, data):
+        self.data = data
+
+    def __eq__(self, o):
+        return o.data == self.data
+
+    def __lt__(self, o):
+        return o.data < self.data
