@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,29 +14,40 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import sys
 import os
 import re
-from calculate.lib.datavars import Variable,ReadonlyVariable,VariableError
+from calculate.lib.datavars import ReadonlyVariable
 from calculate.lib.utils.files import readFile, readLinesFile, listDirectory
 from calculate.lib.utils.device import lspci, getUdevDeviceInfo
 from itertools import *
 
+_ = lambda x: x
+from calculate.lib.cl_lang import setLocalTranslate
+
+setLocalTranslate('cl_lib3', sys.modules[__name__])
+
+
 class VariableHrBoardModel(ReadonlyVariable):
     """
     Motherboard model
     """
+
     def get(self):
-        modelFile = "/sys/class/dmi/id/board_name"
-        return readFile(modelFile).strip()
+        model_file = "/sys/class/dmi/id/board_name"
+        return readFile(model_file).strip()
+
 
 class VariableHrBoardVendor(ReadonlyVariable):
     """
     Motherboard vendor
     """
+
     def get(self):
         """Get motherboard vendor"""
-        vendorFile = "/sys/class/dmi/id/board_vendor"
-        return readFile(vendorFile).strip()
+        vendor_file = "/sys/class/dmi/id/board_vendor"
+        return readFile(vendor_file).strip()
+
 
 class VariableHrCdromSet(ReadonlyVariable):
     """
@@ -45,13 +56,14 @@ class VariableHrCdromSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
-        for cdrom in ifilter(lambda x:x.startswith('/sys/block/sr'),
-                     listDirectory('/sys/block',fullPath=True)):
-            if getUdevDeviceInfo(path=cdrom).get('ID_CDROM','') == "1":
+        for cdrom in ifilter(lambda x: x.startswith('/sys/block/sr'),
+                             listDirectory('/sys/block', fullPath=True)):
+            if getUdevDeviceInfo(path=cdrom).get('ID_CDROM', '') == "1":
                 return "on"
         else:
             return "off"
 
+
 class VariableHrCpuNum(ReadonlyVariable):
     """
     Processors count
@@ -61,9 +73,10 @@ class VariableHrCpuNum(ReadonlyVariable):
         self.label = _("Number of processors")
 
     def get(self):
-        cpuinfoFile = "/proc/cpuinfo"
-        return str(len(filter(lambda x:x.startswith("processor"),
-                       readLinesFile(cpuinfoFile))) or 1)
+        cpuinfo_file = "/proc/cpuinfo"
+        return str(len(filter(lambda x: x.startswith("processor"),
+                              readLinesFile(cpuinfo_file))) or 1)
+
 
 class VariableHrVirtual(ReadonlyVariable):
     """
@@ -71,19 +84,20 @@ class VariableHrVirtual(ReadonlyVariable):
     """
 
     def get(self):
-        virtSysDict = {'VirtualBox':'virtualbox',
-                       'VMware':'vmware',
-                       'Qumranet':'qemu'}
-        reVirtInfo = re.compile("|".join(virtSysDict.keys()))
-        devices = lspci(reVirtInfo.search)
+        virt_sys_dict = {'VirtualBox': 'virtualbox',
+                         'VMware': 'vmware',
+                         'Qumranet': 'qemu'}
+        re_virt_info = re.compile("|".join(virt_sys_dict.keys()))
+        devices = lspci(re_virt_info.search)
         for device in devices.values():
-            nameRes = reVirtInfo.search(device['name'])
-            if not nameRes:
-                nameRes = reVirtInfo.search(device['vendor'])
-            if nameRes:
-                return virtSysDict[nameRes.group()]
+            name_res = re_virt_info.search(device['name'])
+            if not name_res:
+                name_res = re_virt_info.search(device['vendor'])
+            if name_res:
+                return virt_sys_dict[name_res.group()]
         return ""
 
+
 class VariableHrLaptop(ReadonlyVariable):
     """
     Laptop variable.
@@ -93,25 +107,28 @@ class VariableHrLaptop(ReadonlyVariable):
 
     def get(self):
         """Laptop vendor"""
-        chassisType = '/sys/class/dmi/id/chassis_type'
-        boardVendor = '/sys/class/dmi/id/board_vendor'
-        notebookChassis = ['1','8','10']
-        if readFile(chassisType).strip() in notebookChassis:
-            return (readFile(boardVendor).strip().split(" ")[0]).lower() or \
-                "unknown"
+        chassis_type = '/sys/class/dmi/id/chassis_type'
+        board_vendor = '/sys/class/dmi/id/board_vendor'
+        notebook_chassis = ['1', '8', '10']
+        if readFile(chassis_type).strip() in notebook_chassis:
+            vendor = (readFile(board_vendor).strip().split(" ")[0]).lower()
+            return vendor or "unknown"
         return ""
 
+
 class VariableHrLaptopModel(ReadonlyVariable):
     """
     Laptop model name
     """
+
     def get(self):
-        boardName = '/sys/class/dmi/id/board_name'
-        if self.Get('hr_laptop') and os.access(boardName,os.R_OK):
-            valBoardName = readFile(boardName).strip()
-            return valBoardName or "unknown"
+        board_name = '/sys/class/dmi/id/board_name'
+        if self.Get('hr_laptop') and os.access(board_name, os.R_OK):
+            val_board_name = readFile(board_name).strip()
+            return val_board_name or "unknown"
         return ""
 
+
 class VariableHrVideoName(ReadonlyVariable):
     """
     Video vendor full name
@@ -121,16 +138,17 @@ class VariableHrVideoName(ReadonlyVariable):
         self.label = _("Videocard")
 
     def get(self):
-        pciVideo = list(sorted(lspci("VGA compatible").items()))
-        if pciVideo:
-            pciVideo = pciVideo[0][1]
-            vendor=pciVideo.get("vendor","").split(" ")[0]
-            name=pciVideo.get("name","")
+        pci_video = list(sorted(lspci("VGA compatible").items()))
+        if pci_video:
+            pci_video = pci_video[0][1]
+            vendor = pci_video.get("vendor", "").split(" ")[0]
+            name = pci_video.get("name", "")
             if "[" in name and "]" in name:
                 name = name.partition("[")[2].partition("]")[0]
-            return "{vendor} {name}".format(vendor=vendor,name=name)
+            return "{vendor} {name}".format(vendor=vendor, name=name)
         return ""
 
+
 class VariableHrVideo(ReadonlyVariable):
     """
     Videocard vendor shortname (ati,nvidia,intel,via,vmware or other)
@@ -139,9 +157,9 @@ class VariableHrVideo(ReadonlyVariable):
     def get(self):
         """Videocard vendor"""
         line = self.Get('hr_video_name').lower()
-        if any(x in line for x in ("nvidia","geforce")):
+        if any(x in line for x in ("nvidia", "geforce")):
             return "nvidia"
-        if any(x in line for x in ("ati","radeon")):
+        if any(x in line for x in ("ati", "radeon")):
             return "ati"
         elif "intel" in line:
             return "intel"
